@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,16 +21,16 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.api_core import operation as ga_operation  # type: ignore
+from google.api_core import operation as gac_operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.firestore_admin_v1.services.firestore_admin import pagers
 from google.cloud.firestore_admin_v1.types import field
@@ -41,8 +39,7 @@ from google.cloud.firestore_admin_v1.types import firestore_admin
 from google.cloud.firestore_admin_v1.types import index
 from google.cloud.firestore_admin_v1.types import index as gfa_index
 from google.cloud.firestore_admin_v1.types import operation as gfa_operation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .transports.base import FirestoreAdminTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import FirestoreAdminGrpcTransport
 from .transports.grpc_asyncio import FirestoreAdminGrpcAsyncIOTransport
@@ -63,7 +60,7 @@ class FirestoreAdminClientMeta(type):
     _transport_registry["grpc_asyncio"] = FirestoreAdminGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[FirestoreAdminTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -88,7 +85,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -122,7 +120,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -139,7 +138,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -158,23 +157,24 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @property
     def transport(self) -> FirestoreAdminTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            FirestoreAdminTransport: The transport used by the client instance.
+            FirestoreAdminTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def collection_group_path(project: str, database: str, collection: str,) -> str:
-        """Return a fully-qualified collection_group string."""
+        """Returns a fully-qualified collection_group string."""
         return "projects/{project}/databases/{database}/collectionGroups/{collection}".format(
             project=project, database=database, collection=collection,
         )
 
     @staticmethod
     def parse_collection_group_path(path: str) -> Dict[str, str]:
-        """Parse a collection_group path into its component segments."""
+        """Parses a collection_group path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/databases/(?P<database>.+?)/collectionGroups/(?P<collection>.+?)$",
             path,
@@ -183,27 +183,27 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def database_path(project: str, database: str,) -> str:
-        """Return a fully-qualified database string."""
+        """Returns a fully-qualified database string."""
         return "projects/{project}/databases/{database}".format(
             project=project, database=database,
         )
 
     @staticmethod
     def parse_database_path(path: str) -> Dict[str, str]:
-        """Parse a database path into its component segments."""
+        """Parses a database path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/databases/(?P<database>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def field_path(project: str, database: str, collection: str, field: str,) -> str:
-        """Return a fully-qualified field string."""
+        """Returns a fully-qualified field string."""
         return "projects/{project}/databases/{database}/collectionGroups/{collection}/fields/{field}".format(
             project=project, database=database, collection=collection, field=field,
         )
 
     @staticmethod
     def parse_field_path(path: str) -> Dict[str, str]:
-        """Parse a field path into its component segments."""
+        """Parses a field path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/databases/(?P<database>.+?)/collectionGroups/(?P<collection>.+?)/fields/(?P<field>.+?)$",
             path,
@@ -212,14 +212,14 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def index_path(project: str, database: str, collection: str, index: str,) -> str:
-        """Return a fully-qualified index string."""
+        """Returns a fully-qualified index string."""
         return "projects/{project}/databases/{database}/collectionGroups/{collection}/indexes/{index}".format(
             project=project, database=database, collection=collection, index=index,
         )
 
     @staticmethod
     def parse_index_path(path: str) -> Dict[str, str]:
-        """Parse a index path into its component segments."""
+        """Parses a index path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/databases/(?P<database>.+?)/collectionGroups/(?P<collection>.+?)/indexes/(?P<index>.+?)$",
             path,
@@ -228,7 +228,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -241,7 +241,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -252,7 +252,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -263,7 +263,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -274,7 +274,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -288,12 +288,12 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, FirestoreAdminTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the firestore admin client.
+        """Instantiates the firestore admin client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -348,9 +348,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -362,12 +363,14 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -382,8 +385,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -407,7 +410,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> ga_operation.Operation:
+    ) -> gac_operation.Operation:
         r"""Creates a composite index. This returns a
         [google.longrunning.Operation][google.longrunning.Operation]
         which may be used to track the status of the creation. The
@@ -432,7 +435,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``index`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -463,10 +465,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.CreateIndexRequest):
             request = firestore_admin.CreateIndexRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if index is not None:
@@ -486,7 +486,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Wrap the response in an operation future.
-        response = ga_operation.from_gapic(
+        response = gac_operation.from_gapic(
             response,
             self._transport.operations_client,
             gfa_index.Index,
@@ -518,7 +518,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -550,10 +549,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.ListIndexesRequest):
             request = firestore_admin.ListIndexesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -601,7 +598,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -631,10 +627,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.GetIndexRequest):
             request = firestore_admin.GetIndexRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -676,7 +670,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -699,10 +692,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.DeleteIndexRequest):
             request = firestore_admin.DeleteIndexRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -743,7 +734,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -775,10 +765,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.GetFieldRequest):
             request = firestore_admin.GetFieldRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -806,7 +794,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> ga_operation.Operation:
+    ) -> gac_operation.Operation:
         r"""Updates a field configuration. Currently, field updates apply
         only to single field index configuration. However, calls to
         [FirestoreAdmin.UpdateField][google.firestore.admin.v1.FirestoreAdmin.UpdateField]
@@ -833,7 +821,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``field`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -869,10 +856,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.UpdateFieldRequest):
             request = firestore_admin.UpdateFieldRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if field is not None:
                 request.field = field
 
@@ -892,7 +877,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Wrap the response in an operation future.
-        response = ga_operation.from_gapic(
+        response = gac_operation.from_gapic(
             response,
             self._transport.operations_client,
             gfa_field.Field,
@@ -931,7 +916,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -963,10 +947,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.ListFieldsRequest):
             request = firestore_admin.ListFieldsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1000,7 +982,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> ga_operation.Operation:
+    ) -> gac_operation.Operation:
         r"""Exports a copy of all or a subset of documents from
         Google Cloud Firestore to another storage system, such
         as Google Cloud Storage. Recent updates to documents may
@@ -1023,7 +1005,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1057,10 +1038,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.ExportDocumentsRequest):
             request = firestore_admin.ExportDocumentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1078,7 +1057,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Wrap the response in an operation future.
-        response = ga_operation.from_gapic(
+        response = gac_operation.from_gapic(
             response,
             self._transport.operations_client,
             gfa_operation.ExportDocumentsResponse,
@@ -1096,7 +1075,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> ga_operation.Operation:
+    ) -> gac_operation.Operation:
         r"""Imports documents into Google Cloud Firestore.
         Existing documents with the same name are overwritten.
         The import occurs in the background and its progress can
@@ -1116,7 +1095,6 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1158,10 +1136,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore_admin.ImportDocumentsRequest):
             request = firestore_admin.ImportDocumentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1179,10 +1155,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Wrap the response in an operation future.
-        response = ga_operation.from_gapic(
+        response = gac_operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=gfa_operation.ImportDocumentsMetadata,
         )
 
