@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.firestore_admin_v1.types import field as gfa_field
 from google.cloud.firestore_admin_v1.types import index as gfa_index
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -53,8 +50,7 @@ class CreateIndexRequest(proto.Message):
             Required. The composite index to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     index = proto.Field(proto.MESSAGE, number=2, message=gfa_index.Index,)
 
 
@@ -76,13 +72,10 @@ class ListIndexesRequest(proto.Message):
             that may be used to get the next page of results.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
-
-    page_token = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
+    page_token = proto.Field(proto.STRING, number=4,)
 
 
 class ListIndexesResponse(proto.Message):
@@ -103,8 +96,7 @@ class ListIndexesResponse(proto.Message):
         return self
 
     indexes = proto.RepeatedField(proto.MESSAGE, number=1, message=gfa_index.Index,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetIndexRequest(proto.Message):
@@ -117,7 +109,7 @@ class GetIndexRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteIndexRequest(proto.Message):
@@ -130,7 +122,7 @@ class DeleteIndexRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateFieldRequest(proto.Message):
@@ -147,8 +139,9 @@ class UpdateFieldRequest(proto.Message):
     """
 
     field = proto.Field(proto.MESSAGE, number=1, message=gfa_field.Field,)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class GetFieldRequest(proto.Message):
@@ -161,7 +154,7 @@ class GetFieldRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/fields/{field_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListFieldsRequest(proto.Message):
@@ -188,13 +181,10 @@ class ListFieldsRequest(proto.Message):
             that may be used to get the next page of results.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
-
-    page_token = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
+    page_token = proto.Field(proto.STRING, number=4,)
 
 
 class ListFieldsResponse(proto.Message):
@@ -215,8 +205,7 @@ class ListFieldsResponse(proto.Message):
         return self
 
     fields = proto.RepeatedField(proto.MESSAGE, number=1, message=gfa_field.Field,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class ExportDocumentsRequest(proto.Message):
@@ -242,11 +231,9 @@ class ExportDocumentsRequest(proto.Message):
             generated based on the start time.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    collection_ids = proto.RepeatedField(proto.STRING, number=2)
-
-    output_uri_prefix = proto.Field(proto.STRING, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    collection_ids = proto.RepeatedField(proto.STRING, number=2,)
+    output_uri_prefix = proto.Field(proto.STRING, number=3,)
 
 
 class ImportDocumentsRequest(proto.Message):
@@ -267,11 +254,9 @@ class ImportDocumentsRequest(proto.Message):
             [google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix][google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix].
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    collection_ids = proto.RepeatedField(proto.STRING, number=2)
-
-    input_uri_prefix = proto.Field(proto.STRING, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    collection_ids = proto.RepeatedField(proto.STRING, number=2,)
+    input_uri_prefix = proto.Field(proto.STRING, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
