@@ -112,6 +112,23 @@ class AsyncCollectionReference(BaseCollectionReference):
         write_result = await document_ref.create(document_data, **kwargs)
         return write_result.update_time, document_ref
 
+    def document(
+        self, document_id: str = None
+    ) -> async_document.AsyncDocumentReference:
+        """Create a sub-document underneath the current collection.
+
+        Args:
+            document_id (Optional[str]): The document identifier
+                within the current collection. If not provided, will default
+                to a random 20 character string composed of digits,
+                uppercase and lowercase and letters.
+
+        Returns:
+            :class:`~google.cloud.firestore_v1.document.async_document.AsyncDocumentReference`:
+            The child document.
+        """
+        return super(AsyncCollectionReference, self).document(document_id)
+
     async def list_documents(
         self,
         page_size: int = None,
