@@ -14,14 +14,10 @@
 
 """Utilities for managing / converting field paths to / from strings."""
 
-try:
-    from collections import abc as collections_abc
-except ImportError:  # Python 2.7
-    import collections as collections_abc
+from collections import abc
 
 import re
-
-import six
+from typing import Iterable
 
 
 _FIELD_PATH_MISSING_TOP = "{!r} is not contained in the data"
@@ -47,7 +43,7 @@ TOKENS_PATTERN = "|".join("(?P<{}>{})".format(*pair) for pair in PATH_ELEMENT_TO
 TOKENS_REGEX = re.compile(TOKENS_PATTERN)
 
 
-def _tokenize_field_path(path):
+def _tokenize_field_path(path: str):
     """Lex a field path into tokens (including dots).
 
     Args:
@@ -68,7 +64,7 @@ def _tokenize_field_path(path):
         raise ValueError("Path {} not consumed, residue: {}".format(path, path[pos:]))
 
 
-def split_field_path(path):
+def split_field_path(path: str):
     """Split a field path into valid elements (without dots).
 
     Args:
@@ -103,7 +99,7 @@ def split_field_path(path):
     return elements
 
 
-def parse_field_path(api_repr):
+def parse_field_path(api_repr: str):
     """Parse a **field path** from into a list of nested field names.
 
     See :func:`field_path` for more on **field paths**.
@@ -132,7 +128,7 @@ def parse_field_path(api_repr):
     return field_names
 
 
-def render_field_path(field_names):
+def render_field_path(field_names: Iterable[str]):
     """Create a **field path** from a list of nested field names.
 
     A **field path** is a ``.``-delimited concatenation of the field
@@ -176,7 +172,7 @@ def render_field_path(field_names):
 get_field_path = render_field_path  # backward-compatibility
 
 
-def get_nested_value(field_path, data):
+def get_nested_value(field_path: str, data: dict):
     """Get a (potentially nested) value from a dictionary.
 
     If the data is nested, for example:
@@ -234,7 +230,7 @@ def get_nested_value(field_path, data):
 
     nested_data = data
     for index, field_name in enumerate(field_names):
-        if isinstance(nested_data, collections_abc.Mapping):
+        if isinstance(nested_data, abc.Mapping):
             if field_name in nested_data:
                 nested_data = nested_data[field_name]
             else:
@@ -271,13 +267,13 @@ class FieldPath(object):
 
     def __init__(self, *parts):
         for part in parts:
-            if not isinstance(part, six.string_types) or not part:
+            if not isinstance(part, str) or not part:
                 error = "One or more components is not a string or is empty."
                 raise ValueError(error)
         self.parts = tuple(parts)
 
     @classmethod
-    def from_api_repr(cls, api_repr):
+    def from_api_repr(cls, api_repr: str):
         """Factory: create a FieldPath from the string formatted per the API.
 
         Args:
@@ -294,7 +290,7 @@ class FieldPath(object):
         return cls(*parse_field_path(api_repr))
 
     @classmethod
-    def from_string(cls, path_string):
+    def from_string(cls, path_string: str):
         """Factory: create a FieldPath from a unicode string representation.
 
         This method splits on the character `.` and disallows the
@@ -353,7 +349,7 @@ class FieldPath(object):
         if isinstance(other, FieldPath):
             parts = self.parts + other.parts
             return FieldPath(*parts)
-        elif isinstance(other, six.string_types):
+        elif isinstance(other, str):
             parts = self.parts + FieldPath.from_string(other).parts
             return FieldPath(*parts)
         else:
@@ -382,7 +378,7 @@ class FieldPath(object):
 
         Returns: Set[:class:`FieldPath`]
         """
-        indexes = six.moves.range(1, len(self.parts))
+        indexes = range(1, len(self.parts))
         return {FieldPath(*self.parts[:index]) for index in indexes}
 
     @staticmethod
