@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -33,10 +31,10 @@ from typing import (
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -49,9 +47,8 @@ from google.cloud.firestore_v1.types import document as gf_document
 from google.cloud.firestore_v1.types import firestore
 from google.cloud.firestore_v1.types import query
 from google.cloud.firestore_v1.types import write as gf_write
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 from .transports.base import FirestoreTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import FirestoreGrpcTransport
 from .transports.grpc_asyncio import FirestoreGrpcAsyncIOTransport
@@ -70,7 +67,7 @@ class FirestoreClientMeta(type):
     _transport_registry["grpc_asyncio"] = FirestoreGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[FirestoreTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -101,7 +98,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -135,7 +133,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -152,7 +151,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -171,16 +170,17 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @property
     def transport(self) -> FirestoreTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            FirestoreTransport: The transport used by the client instance.
+            FirestoreTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -193,7 +193,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -204,7 +204,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -215,7 +215,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -226,7 +226,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -240,12 +240,12 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, FirestoreTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the firestore client.
+        """Instantiates the firestore client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -300,9 +300,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -314,12 +315,14 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -334,8 +337,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -364,7 +367,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.GetDocumentRequest):
                 The request object. The request for
                 [Firestore.GetDocument][google.firestore.v1.Firestore.GetDocument].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -378,7 +380,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.GetDocumentRequest.
         # There's no risk of modifying the input as we've already verified
@@ -416,7 +417,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.ListDocumentsRequest):
                 The request object. The request for
                 [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -433,7 +433,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.ListDocumentsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -501,7 +500,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -530,10 +528,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.UpdateDocumentRequest):
             request = firestore.UpdateDocumentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if document is not None:
                 request.document = document
             if update_mask is not None:
@@ -580,7 +576,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -603,10 +598,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.DeleteDocumentRequest):
             request = firestore.DeleteDocumentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -641,7 +634,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.BatchGetDocumentsRequest):
                 The request object. The request for
                 [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -655,7 +647,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.BatchGetDocumentsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -701,7 +692,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``database`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -730,10 +720,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.BeginTransactionRequest):
             request = firestore.BeginTransactionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if database is not None:
                 request.database = database
 
@@ -784,7 +772,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``writes`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -813,10 +800,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.CommitRequest):
             request = firestore.CommitRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if database is not None:
                 request.database = database
             if writes is not None:
@@ -868,7 +853,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``transaction`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -891,10 +875,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.RollbackRequest):
             request = firestore.RollbackRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if database is not None:
                 request.database = database
             if transaction is not None:
@@ -929,7 +911,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.RunQueryRequest):
                 The request object. The request for
                 [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -943,7 +924,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.RunQueryRequest.
         # There's no risk of modifying the input as we've already verified
@@ -985,7 +965,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.PartitionQueryRequest):
                 The request object. The request for
                 [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1002,7 +981,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.PartitionQueryRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1149,7 +1127,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1181,10 +1158,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, firestore.ListCollectionIdsRequest):
             request = firestore.ListCollectionIdsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1234,7 +1209,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.BatchWriteRequest):
                 The request object. The request for
                 [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1248,7 +1222,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.BatchWriteRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1286,7 +1259,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             request (google.cloud.firestore_v1.types.CreateDocumentRequest):
                 The request object. The request for
                 [Firestore.CreateDocument][google.firestore.v1.Firestore.CreateDocument].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1300,7 +1272,6 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a firestore.CreateDocumentRequest.
         # There's no risk of modifying the input as we've already verified
